@@ -1,4 +1,4 @@
-from retriever_research.actors.pykka_extensions.custom_actor import RetrieverThreadingActor
+from retriever_research.actors.pykka_extensions import RetrieverThreadingActor
 from retriever_research.actors.chunk_sequencer import ChunkSequencer
 from retriever_research.actors.file_chunker import FileChunker
 from retriever_research.actors.file_list_generator import FileListGenerator
